@@ -1,7 +1,7 @@
 package Perinci::CmdLine::Lite;
 
-our $DATE = '2017-06-19'; # DATE
-our $VERSION = '1.74_003'; # VERSION
+our $DATE = '2017-06-21'; # DATE
+our $VERSION = '1.74_004'; # VERSION
 
 use 5.010001;
 # use strict; # already enabled by Mo
@@ -172,23 +172,15 @@ sub hook_after_parse_argv {
 
     # set up log adapter
     if ($self->log) {
-        if ($ENV{LOG_ANY}) {
-            require Log::Any::Adapter;
-            Log::Any::Adapter->set(
-                'Screen',
-                min_level => $r->{log_level} // $self->log_level,
-                formatter => sub { $self->program_name . ": $_[1]" },
-            );
-        } else {
-            require Log::ger::Output;
-            my $str_level = $r->{log_level} // $self->log_level;
-            $str_level = 'warn' if $str_level eq 'warning';
-            $Log::ger::Current_Level = $Log::ger::Levels{$str_level} // 3;
-            Log::ger::Output->set(
-                'Screen',
-                formatter => sub { $self->program_name . ": $_[0]" },
-            );
-        }
+        require Log::ger::Output;
+        require Log::ger::Util;
+        my $str_level = $r->{log_level} // $self->log_level;
+        $Log::ger::Current_Level =
+            Log::ger::Util::numeric_level($str_level) // 3;
+        Log::ger::Output->set(
+            'Screen',
+            formatter => sub { $self->program_name . ": $_[0]" },
+        );
     }
 }
 
@@ -535,7 +527,7 @@ Perinci::CmdLine::Lite - A Rinci/Riap-based command-line application framework
 
 =head1 VERSION
 
-This document describes version 1.74_003 of Perinci::CmdLine::Lite (from Perl distribution Perinci-CmdLine-Lite), released on 2017-06-19.
+This document describes version 1.74_004 of Perinci::CmdLine::Lite (from Perl distribution Perinci-CmdLine-Lite), released on 2017-06-21.
 
 =head1 SYNOPSIS
 
